==> dokuwiki-2011.05.25a.tgz: dokuwiki/lib/plugins/plugin/lang/de-informal/lang.php <==
<?php
/**
 * German (informal) language file
 *
 * @author Alexander Fischer <tbanus@os-forge.net>
 * @author Juergen Schwarzer <jschwarzer@freenet.de>
 * @author Marcel Metz <marcel_metz@gmx.de>
 * @author Matthias Schulte <post@lupo49.de>
 * @author Christian Wichmann <nospam@zone0.de>
 */
$lang['menu']                  = 'Plugins verwalten';
$lang['download']              = 'Herunterladen und installieren einer neuen Erweiterung';
$lang['manage']                = 'Installierte Erweiterungen';
$lang['btn_info']              = 'Information';
$lang['btn_update']            = 'aktualisieren';
$lang['btn_delete']            = 'löschen';
$lang['btn_settings']          = 'Einstellungen';
$lang['btn_download']          = 'Herunterladen';
$lang['btn_enable']            = 'Speichern';
$lang['url']                   = 'URL';
$lang['installed']             = 'Installiert:';
$lang['lastupdate']            = 'Letzte Aktualisierung:';
$lang['source']                = 'Quellen:';
$lang['unknown']               = 'unbekannt';
$lang['updating']              = 'Aktualisiere...';
$lang['updated']               = 'Erweiterung %s wurde erfolgreich aktualisiert.';
$lang['updates']               = 'Die folgenden Erweiterungen wurden erfolgreich aktualisiert.';
$lang['update_none']           = 'Keine Aktualisierungen gefunden.';
$lang['deleting']              = 'Lösche...';
$lang['deleted']               = 'Erweiterung %s wurde gelöscht.';
$lang['downloading']           = 'Herunterladen...';
$lang['downloaded']            = 'Erweiterung %s wurde erfolgreich installiert';
$lang['downloads']             = 'Die folgenden Erweiterungen wurden erfolgreich installiert:';
$lang['download_none']         = 'Keine Erweiterungen gefunden oder es trat ein unbekanntest Problem beim Herunterladen und Installieren auf.';
$lang['plugin']                = 'Erweiterung:';
$lang['components']            = 'Komponenten';
$lang['noinfo']                = 'Diese Erweiterung gab keine Information zurück - sie könnte ungültig sein.';
$lang['name']                  = 'Name:';
$lang['date']                  = 'Datum:';
$lang['type']                  = 'Typ:';
$lang['desc']                  = 'Beschreibung:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Internet:';
$lang['error']                 = 'Es ist ein unbekannter Fehler aufgetreten.';
$lang['error_download']        = 'Nicht möglich die Erweiterung herunterzuladen: %s';
$lang['error_badurl']          = 'Vermute schlechte URL - nicht möglich den Dateinamen aus der URL zu ermitteln';
$lang['error_dircreate']       = 'Nicht möglich einen temporären Ordner zu erstellen um den Download zu empfangen.';
$lang['error_decompress']      = 'Dem Erweiterungsmanager war es nicht möglich die heruntergeladene Datei zu dekomprimieren. Dies kann an einem defekten Download liegen, in diesem Fall sollten Sie es erneut versuchen; oder das Format mit dem die Datei komprimiert ist, ist unbekannt, da müssen Sie die Erweiterung manuell herunterladen und installieren. ';
$lang['error_copy']            = 'Es trat ein Dateifehler beim Kopieren der Installationsdateien für die Erweiterung <em>%s</em> auf: Die Festplatte könnte voll oder die Zugriffsrechte verweigert worden sein. Dies führt zu einer teilweise installierten Erweiterung und belässt dein Wiki in einem instabilen Zustand.';
$lang['error_delete']          = 'Es trat ein Fehler beim Löschen der Erweiterung <em>%s</em> auf. Die wahrscheinlichste Ursache ist eine unzureichende Datei- oder Ordnerzugriffserlaubnis.';
$lang['enabled']               = 'Erweiterung %s aktiviert.';
$lang['notenabled']            = 'Erweiterung %s konnte nicht aktiviert werden. Überprüfen sie die Zugriffsberechtigung der Datei.';
$lang['disabled']              = 'Erweiterung %s deaktiviert.';
$lang['notdisabled']           = 'Erweiterung %s konnte nicht deaktiviert werden - überprüfe Dateiberechtigungen';
$lang['packageinstalled']      = 'Plugin-Paket (%d Plugin%s: %s) erfolgreich installiert.';

==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/plugin/lang/de-informal/lang.php <==
<?php
/**
 * German (informal) language file
 *
 * @author Alexander Fischer <tbanus@os-forge.net>
 * @author Juergen Schwarzer <jschwarzer@freenet.de>
 * @author Marcel Metz <marcel_metz@gmx.de>
 * @author Matthias Schulte <post@lupo49.de>
 * @author Christian Wichmann <nospam@zone0.de>
 * @author Pierre Corell <info@joomla-praxis.de>
 * @author Frank Loizzi <contact@software.bacal.de>
 */
$lang['menu']                  = 'Plugins verwalten';
$lang['download']              = 'Herunterladen und installieren einer neuen Erweiterung';
$lang['manage']                = 'Installierte Erweiterungen';
$lang['btn_info']              = 'Information';
$lang['btn_update']            = 'aktualisieren';
$lang['btn_delete']            = 'löschen';
$lang['btn_settings']          = 'Einstellungen';
$lang['btn_download']          = 'Herunterladen';
$lang['btn_enable']            = 'Speichern';
$lang['url']                   = 'URL';
$lang['installed']             = 'Installiert:';
$lang['lastupdate']            = 'Letzte Aktualisierung:';
$lang['source']                = 'Quellen:';
$lang['unknown']               = 'unbekannt';
$lang['updating']              = 'Aktualisiere...';
$lang['updated']               = 'Erweiterung %s wurde erfolgreich aktualisiert.';
$lang['updates']               = 'Die folgenden Erweiterungen wurden erfolgreich aktualisiert.';
$lang['update_none']           = 'Keine Aktualisierungen gefunden.';
$lang['deleting']              = 'Lösche...';
$lang['deleted']               = 'Erweiterung %s wurde gelöscht.';
$lang['downloading']           = 'Herunterladen...';
$lang['downloaded']            = 'Erweiterung %s wurde erfolgreich installiert';
$lang['downloads']             = 'Die folgenden Erweiterungen wurden erfolgreich installiert:';
$lang['download_none']         = 'Keine Erweiterungen gefunden oder es trat ein unbekanntest Problem beim Herunterladen und Installieren auf.';
$lang['plugin']                = 'Erweiterung:';
$lang['components']            = 'Komponenten';
$lang['noinfo']                = 'Diese Erweiterung gab keine Information zurück - sie könnte ungültig sein.';
$lang['name']                  = 'Name:';
$lang['date']                  = 'Datum:';
$lang['type']                  = 'Typ:';
$lang['desc']                  = 'Beschreibung:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Internet:';
$lang['error']                 = 'Es ist ein unbekannter Fehler aufgetreten.';
$lang['error_download']        = 'Nicht möglich die Erweiterung herunterzuladen: %s';
$lang['error_badurl']          = 'Vermute schlechte URL - nicht möglich den Dateinamen aus der URL zu ermitteln';
$lang['error_dircreate']       = 'Nicht möglich einen temporären Ordner zu erstellen um den Download zu empfangen.';
$lang['error_decompress']      = 'Dem Erweiterungsmanager war es nicht möglich die heruntergeladene Datei zu dekomprimieren. Dies kann an einem defekten Download liegen, in diesem Fall sollten Sie es erneut versuchen; oder das Format mit dem die Datei komprimiert ist, ist unbekannt, da müssen Sie die Erweiterung manuell herunterladen und installieren. ';
$lang['error_copy']            = 'Es trat ein Dateifehler beim Kopieren der Installationsdateien für die Erweiterung <em>%s</em> auf: Die Festplatte könnte voll oder die Zugriffsrechte verweigert worden sein. Dies führt zu einer teilweise installierten Erweiterung und belässt dein Wiki in einem instabilen Zustand.';
$lang['error_delete']          = 'Es trat ein Fehler beim Löschen der Erweiterung <em>%s</em> auf. Die wahrscheinlichste Ursache ist eine unzureichende Datei- oder Ordnerzugriffserlaubnis.';
$lang['enabled']               = 'Erweiterung %s aktiviert.';
$lang['notenabled']            = 'Erweiterung %s konnte nicht aktiviert werden. Überprüfen sie die Zugriffsberechtigung der Datei.';
$lang['disabled']              = 'Erweiterung %s deaktiviert.';
$lang['notdisabled']           = 'Erweiterung %s konnte nicht deaktiviert werden - überprüfe Dateiberechtigungen';
$lang['packageinstalled']      = 'Plugin-Paket (%d Plugin(s): %s) erfolgreich installiert.';
